==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/graffiti-canvas.cc <==
//$Id: graffiti-canvas.cc,v 1.7 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "graffiti-canvas.h"

#include "form-editor.h"

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gnome-canvas-pixbuf.h>

#include "pixmaps/graffiti-canvas.xpm"

using namespace Guikachu::GUI::FormEditor;

GraffitiCanvasItem::GraffitiCanvasItem (Widgets::Graffiti *widget_,
					FormEditor::Form  *form):
    CanvasItem (widget_, form),
    widget (widget_),
    group (0)
{
    update ();
}

void GraffitiCanvasItem::update ()
{
    if (group)
	delete group;
    
    group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);    
    
    GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)graffiti_canvas_xpm);
    gnome_canvas_item_new (group->gtkobj (),
			   gnome_canvas_pixbuf_get_type (),
			   "pixbuf", pixbuf,
			   "x", (double)widget->x,
			   "y", (double)widget->y,
			   0);
    gdk_pixbuf_unref (pixbuf);

    set_canvas_item (group);
}

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/graffiti-canvas.cc <==
//$Id: graffiti-canvas.cc,v 1.12 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "graffiti-canvas.h"

#include "form-editor.h"

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gnome-canvas-pixbuf.h>

#include "pixmaps/graffiti-canvas.xpm"

using namespace Guikachu::GUI::FormEditor;

GraffitiCanvasItem::GraffitiCanvasItem (Widgets::Graffiti  *widget_,
					Gnome::CanvasGroup *parent_group):
    CanvasItem (widget_, parent_group),
    WidgetCanvasItem (widget_, parent_group),
    widget (widget_),
    group (0)
{
    update ();
}

void GraffitiCanvasItem::update ()
{
    if (group)
	delete group;
    
    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
    
    GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)graffiti_canvas_xpm);
    gnome_canvas_item_new (group->gtkobj (),
			   gnome_canvas_pixbuf_get_type (),
			   "pixbuf", pixbuf,
			   "x", (double)widget->x,
			   "y", (double)widget->y,
			   0);
    gdk_pixbuf_unref (pixbuf);

    set_canvas_item (group);
}
